import stan
import arviz as az
import scipy.stats as ss
import matplotlib.pyplot as plt

model_script = """
    data {
        int N;
        int k;
    }
    parameters {
        real<lower = 0.0, upper = 1.0> p;
    }
    model {
        k ~ binomial(N, p);
    }
"""

Stan_Data = {'N': 10, 'k': 7}
sm = stan.build(model_script, data = Stan_Data)
fit = sm.sample()
#
#      Convert sampling data into an InferenceData class
#
i_data = az.from_pystan(posterior=fit, posterior_model=sm)
smry = az.summary(i_data)
print('Summary...\n', smry)

az.plot_trace(i_data)
plt.tight_layout()
plt.savefig('FigTrace.png')
plt.show()

az.plot_posterior(i_data, point_estimate = 'median')
plt.savefig('FigRho.png')
plt.show()

